@@ -11,7 +11,7 @@ step_to_chull <- function(obj) {
   sim_mat <- Reduce("+", obj$sim$stats)
   check_obs <- t(ergm.etagrad(obj$est$theta, obj$net$etamap) %*% obj$net$obs_stats_step)
   check_sim <- t(ergm.etagrad(obj$est$theta, obj$net$etamap) %*% t(sim_mat))
-  check_ <- is.inCH(check_obs, check_sim)
+  check_ <- is.inCHv3.9(check_obs, check_sim)
   if (!check_) { 
     step_flag <- TRUE
     iter <- 1
@@ -57,7 +57,7 @@ step_to_chull <- function(obj) {
     }
     obj$net$obs_stats_step <- obj$net$obs_stats * 1.05 * obj$est$gamma + (1 - 1.05 * obj$est$gamma) * sim_mean
     check_obs <- t(ergm.etagrad(obj$est$theta, obj$net$etamap) %*% obj$net$obs_stats_step)
-    check_ <- suppressMessages(is.inCH(check_obs, check_sim))
+    check_ <- suppressMessages(is.inCHv3.9(check_obs, check_sim))
     iter <- iter + 1
   }
   if (step_flag) { 
@@ -81,3 +81,5 @@ step_to_chull <- function(obj) {
   }
   return(obj)
 }
+
+
